import java.util.ArrayList;

/**
 * A class to hold details of audio files.
 *
 * @author David J. Barnes and Michael Kolling
 * @version 2011.07.31
 */
public class MusicCollection {
    // An ArrayList for storing the file names of music files.
    private ArrayList<Music> files;
    // A player for the music files.
    private MusicPlayer player;

    /**
     * Create a MusicCollection
     */
    public MusicCollection(MusicPlayer player) {
        files=new ArrayList<>();
        this.player=player;
    }

    /**
     * Add a file to the collection.
     *
     * @param track The track to be added.
     */
    public void addFile(Music track) {
        files.add(track);
    }

    /**
     * Return the number of files in the collection.
     *
     * @return The number of files in the collection.
     */
    public int getNumberOfFiles() {
        return files.size();
    }

    /**
     * List a file from the collection.
     *
     * @param index The index of the file to be listed.
     */
    public void listFile(int index) {
        if (validIndex(index)) {
            Music track = files.get(index);
            System.out.println(track.getName() + "\nArtist:\t" + track.getArtist() +
                    "\nDistributed in:\t" + track.getDistributionYear() + "\nDirectory:\t" +
                    track.getFileDirectory());
        }

    }

    /**
     * Show a list of all the files in the collection.
     */
    public void listAllFiles() {
        int i = 0;

        for (Music track : files) {
            i++;
            System.out.println(i+"- "+track.getName() + "\nArtist:\t" + track.getArtist() +
                    "\nDistributed in:\t" + track.getDistributionYear() + "\nDirectory:\t" +
                    track.getFileDirectory()+"\n");
        }
    }

    /**
     * Remove a file from the collection.
     *
     * @param index The index of the file to be removed.
     */
    public void removeFile(int index) {
        if (validIndex(index))
            files.remove(index);
    }

    /**
     * Start playing a file in the collection.
     * Use stopPlaying() to stop it playing.
     *
     * @param index The index of the file to be played.
     */
    public void startPlaying(int index) {
        if (validIndex(index))
            player.startPlaying(files.get(index).getName());
    }

    /**
     * Stop the player and shows a message for that.
     */
    public void stopPlaying() {
        player.stop();
        System.out.println("Player Stopped Successfully...\n");
    }


    /**
     * Determine whether the given index is valid for the collection.
     * Print an error message if it is not.
     *
     * @param index The index to be checked.
     * @return true if the index is valid, false otherwise.
     */
    private boolean validIndex(int index) {
        // The return value.
        // Set according to whether the index is valid or not.
        if (index >= files.size()) System.out.println("Wrong Index!");

        return index < files.size() && index >= 0;
    }

    /**
     * This function will iterate through our collection and
     * to search for given keyword.
     *
     * @param keyWord the keyword which is being searched
     * @return an object containing all matches
     */
    public MusicCollection search(String keyWord) {
        MusicCollection searchResults = new MusicCollection(new MusicPlayer());
        for (Music track : files) {
            if (track.getFileDirectory().contains(keyWord) || track.getArtist().equals(keyWord) ||
                    track.getName().equals(keyWord))
                searchResults.addFile(track);
        }
        return searchResults;
    }

    /**
     * @param index the index of the file
     * @return the file with the given index in our collection
     */
    public Music getFile(int index) {

        return files.get(index);

    }
}